@@ -3,7 +3,7 @@
 makeFeatSelControlGA = function(same.resampling.instance = TRUE, impute.val = NULL,
   maxit = NA_integer_, max.features = NA_integer_, comma = FALSE, mu = 10L, lambda,
   crossover.rate = 0.5, mutation.rate = 0.05, tune.threshold = FALSE, tune.threshold.args = list(),
-  log.fun = NULL) {
+  log.fun = "default") {
 
   maxit = asCount(maxit, positive = TRUE)
   assertFlag(comma)
