@@ -1,11 +1,11 @@
 makeOptControl = function(same.resampling.instance, impute.val = NULL, tune.threshold = FALSE,
-  tune.threshold.args = list(), log.fun = NULL, final.dw.perc = NULL, ...) {
+  tune.threshold.args = list(), log.fun = "default", final.dw.perc = NULL, ...) {
 
   assertFlag(same.resampling.instance)
   if (!is.null(impute.val))
     assertNumeric(impute.val)
   assertFunction(log.fun,
-    args = c("learner", "task", "resampling", "measures", "par.set", "control", "opt.path", "dob", "x", "y", "remove.nas", "stage"))
+    args = c("learner", "task", "resampling", "measures", "par.set", "control", "opt.path", "dob", "x", "y", "remove.nas", "stage", "prev.stage"))
   assertFlag(tune.threshold)
   makeS3Obj("OptControl",
     same.resampling.instance = same.resampling.instance,
