@@ -9,40 +9,44 @@
 #'
 #' For a general overview on how to integrate a learning algorithm into mlr's system, please read the
 #' section in the online tutorial:
-#' \url{http://mlr-org.github.io/mlr-tutorial/release/html/create_learner/index.html}
+#' <http://mlr-org.github.io/mlr-tutorial/release/html/create_learner/index.html>
 #'
-#' To see all possible properties of a learner, go to: \code{\link{LearnerProperties}}.
+#' To see all possible properties of a learner, go to: [LearnerProperties].
 #'
 #' @template arg_lrncl
-#' @param package [\code{character}]\cr
+#' @param package ([character])\cr
 #'   Package(s) to load for the implementation of the learner.
-#' @param properties [\code{character}]\cr
+#' @param properties ([character])\cr
 #'   Set of learner properties. See above.
-#'   Default is \code{character(0)}.
-#' @param class.weights.param [\code{character(1)}]\cr
+#'   Default is `character(0)`.
+#' @param class.weights.param (`character(1)`)\cr
 #'   Name of the parameter, which can be used for providing class weights.
-#' @param par.set [\code{\link[ParamHelpers]{ParamSet}}]\cr
+#' @param par.set ([ParamHelpers::ParamSet])\cr
 #'   Parameter set of (hyper)parameters and their constraints.
-#'   Dependent parameters with a \code{requires} field must use \code{quote} and not
-#'   \code{expression} to define it.
-#' @param par.vals [\code{list}]\cr
+#'   Dependent parameters with a `requires` field must use `quote` and not
+#'   `expression` to define it.
+#' @param par.vals ([list])\cr
 #'   Always set hyperparameters to these values when the object is constructed.
 #'   Useful when default values are missing in the underlying function.
 #'   The values can later be overwritten when the user sets hyperparameters.
 #'   Default is empty list.
-#' @param name [\code{character(1)}]\cr
+#' @param name (`character(1)`)\cr
 #'   Meaningful name for learner.
-#'   Default is \code{id}.
-#' @param short.name [\code{character(1)}]\cr
+#'   Default is `id`.
+#' @param short.name (`character(1)`)\cr
 #'   Short name for learner.
 #'   Should only be a few characters so it can be used in plots and tables.
-#'   Default is \code{id}.
-#' @param note [\code{character(1)}]\cr
+#'   Default is `id`.
+#' @param note (`character(1)`)\cr
 #'   Additional notes regarding the learner and its integration in mlr.
 #'   Default is \dQuote{}.
-#' @return [\code{\link{RLearner}}]. The specific subclass is one of \code{\link{RLearnerClassif}},
-#'   \code{\link{RLearnerCluster}}, \code{\link{RLearnerMultilabel}},
-#'   \code{\link{RLearnerRegr}}, \code{\link{RLearnerSurv}}.
+#' @param callees ([character])\cr
+#'   Character vector naming all functions of the learner's package being called which
+#'   have a relevant R help page.
+#'   Default is `character(0)`.
+#' @return ([RLearner]). The specific subclass is one of [RLearnerClassif],
+#'   [RLearnerCluster], [RLearnerMultilabel],
+#'   [RLearnerRegr], [RLearnerSurv].
 #' @name RLearner
 #' @rdname RLearner
 #' @aliases RLearnerClassif RLearnerCluster RLearnerMultilabel RLearnerRegr RLearnerSurv
@@ -55,7 +59,7 @@ makeRLearner = function() {
 }
 
 makeRLearnerInternal = function(id, type, package, par.set, par.vals, properties,
-  name = id, short.name = id, note = "") {
+  name = id, short.name = id, note = "", callees) {
 
   # must do that before accessing par.set
   # one case where lazy eval is actually helpful...
@@ -73,6 +77,7 @@ makeRLearnerInternal = function(id, type, package, par.set, par.vals, properties
   assertString(name)
   assertString(short.name)
   assertString(note)
+  assertCharacter(callees, any.missing = FALSE)
   learner = makeLearnerBaseConstructor("RLearner",
     id = id,
     type = type,
@@ -85,6 +90,8 @@ makeRLearnerInternal = function(id, type, package, par.set, par.vals, properties
   learner$name = name
   learner$short.name = short.name
   learner$note = note
+  learner$callees = callees
+  learner$help.list = makeParamHelpList(callees, package, par.set)
   return(learner)
 
 }
@@ -92,10 +99,10 @@ makeRLearnerInternal = function(id, type, package, par.set, par.vals, properties
 #' @export
 #' @rdname RLearner
 makeRLearnerClassif = function(cl, package, par.set, par.vals = list(), properties = character(0L),
-  name = cl, short.name = cl, note = "", class.weights.param = NULL) {
+  name = cl, short.name = cl, note = "", class.weights.param = NULL, callees = character(0L)) {
 
   lrn = addClasses(
-    makeRLearnerInternal(cl, "classif", package, par.set, par.vals, properties, name, short.name, note),
+    makeRLearnerInternal(cl, "classif", package, par.set, par.vals, properties, name, short.name, note, callees),
     c(cl, "RLearnerClassif")
   )
 
@@ -112,36 +119,36 @@ makeRLearnerClassif = function(cl, package, par.set, par.vals = list(), properti
 
 #' @export
 #' @rdname RLearner
-makeRLearnerMultilabel = function(cl, package, par.set, par.vals = list(), properties = character(0L), name = cl, short.name = cl, note = "") {
+makeRLearnerMultilabel = function(cl, package, par.set, par.vals = list(), properties = character(0L), name = cl, short.name = cl, note = "", callees = character(0L)) {
   addClasses(
-    makeRLearnerInternal(cl, "multilabel", package, par.set, par.vals, properties, name, short.name, note),
+    makeRLearnerInternal(cl, "multilabel", package, par.set, par.vals, properties, name, short.name, note, callees),
     c(cl, "RLearnerMultilabel")
   )
 }
 
 #' @export
 #' @rdname RLearner
-makeRLearnerRegr = function(cl, package, par.set, par.vals = list(), properties = character(0L), name = cl, short.name = cl, note = "") {
+makeRLearnerRegr = function(cl, package, par.set, par.vals = list(), properties = character(0L), name = cl, short.name = cl, note = "", callees = character(0L)) {
   addClasses(
-    makeRLearnerInternal(cl, "regr", package, par.set, par.vals, properties, name, short.name, note),
+    makeRLearnerInternal(cl, "regr", package, par.set, par.vals, properties, name, short.name, note, callees),
     c(cl, "RLearnerRegr")
   )
 }
 
 #' @export
 #' @rdname RLearner
-makeRLearnerSurv = function(cl, package, par.set, par.vals = list(), properties = character(0L), name = cl, short.name = cl, note = "") {
+makeRLearnerSurv = function(cl, package, par.set, par.vals = list(), properties = character(0L), name = cl, short.name = cl, note = "", callees = character(0L)) {
   addClasses(
-    makeRLearnerInternal(cl, "surv", package, par.set, par.vals, properties, name, short.name, note),
+    makeRLearnerInternal(cl, "surv", package, par.set, par.vals, properties, name, short.name, note, callees),
     c(cl, "RLearnerSurv")
   )
 }
 
 #' @export
 #' @rdname RLearner
-makeRLearnerCluster = function(cl, package, par.set, par.vals = list(), properties = character(0L), name = cl, short.name = cl, note = "") {
+makeRLearnerCluster = function(cl, package, par.set, par.vals = list(), properties = character(0L), name = cl, short.name = cl, note = "", callees = character(0L)) {
   addClasses(
-    makeRLearnerInternal(cl, "cluster", package, par.set, par.vals, properties, name, short.name, note),
+    makeRLearnerInternal(cl, "cluster", package, par.set, par.vals, properties, name, short.name, note, callees),
     c(cl, "RLearnerCluster")
   )
 }
@@ -149,10 +156,10 @@ makeRLearnerCluster = function(cl, package, par.set, par.vals = list(), properti
 #' @export
 #' @rdname RLearner
 makeRLearnerCostSens = function(cl, package, par.set, par.vals = list(), properties = character(0L),
-  name = cl, short.name = cl, note = "") {
+  name = cl, short.name = cl, note = "", callees = character(0L)) {
 
   lrn = addClasses(
-    makeRLearnerInternal(cl, "costsens", package, par.set, par.vals, properties, name, short.name, note),
+    makeRLearnerInternal(cl, "costsens", package, par.set, par.vals, properties, name, short.name, note, callees),
     c(cl, "RLearnerCostSens")
   )
 
