@@ -10,7 +10,8 @@ makeRLearner.classif.OneR = function() {
     properties = c("twoclass", "multiclass", "missings", "numerics", "factors", "prob"),
     name = "1-R Classifier",
     short.name = "oner",
-    note = "NAs are directly passed to WEKA with `na.action = na.pass`."
+    note = "NAs are directly passed to WEKA with `na.action = na.pass`.",
+    callees = c("OneR", "Weka_control")
   )
 }
 
@@ -18,7 +19,7 @@ makeRLearner.classif.OneR = function() {
 trainLearner.classif.OneR = function(.learner, .task, .subset, .weights = NULL,  ...) {
   f = getTaskFormula(.task)
   ctrl = RWeka::Weka_control(...)
-	RWeka::OneR(f, data = getTaskData(.task, .subset), control = ctrl, na.action = na.pass)
+  RWeka::OneR(f, data = getTaskData(.task, .subset), control = ctrl, na.action = na.pass)
 }
 
 #' @export
