@@ -7,7 +7,8 @@ makeRLearner.classif.lvq1 = function() {
     par.set = makeParamSet(),
     properties = c("twoclass", "multiclass", "numerics"),
     name = "Learning Vector Quantization",
-    short.name = "lvq1"
+    short.name = "lvq1",
+    callees = c("lvq1", "lvqinit", "lvqtest")
   )
 }
 
