@@ -5,14 +5,15 @@ makeRLearner.classif.qda = function() {
     package = "MASS",
     par.set = makeParamSet(
       makeDiscreteLearnerParam(id = "method", default = "moment", values = c("moment", "mle", "mve", "t")),
-      makeNumericLearnerParam(id = "nu", default = 5 , lower = 2, requires = quote(method == "t")),
+      makeNumericLearnerParam(id = "nu", default = 5, lower = 2, requires = quote(method == "t")),
       makeDiscreteLearnerParam(id = "predict.method", values = c("plug-in", "predictive", "debiased"),
         default = "plug-in", when = "predict")
     ),
     properties = c("twoclass", "multiclass", "numerics", "factors", "prob"),
     name = "Quadratic Discriminant Analysis",
     short.name = "qda",
-    note = "Learner parameter `predict.method` maps to `method` in `predict.qda`."
+    note = "Learner parameter `predict.method` maps to `method` in `predict.qda`.",
+    callees = c("qda", "predict.qda")
   )
 }
 
