@@ -14,19 +14,20 @@ makeRLearner.classif.rknn = function(){
     properties = c("twoclass", "multiclass", "numerics", "ordered"),
     name = "Random k-Nearest-Neighbors",
     short.name = "rknn",
-    note = "k restricted to < 99 as the code allocates arrays of static size"
+    note = "k restricted to < 99 as the code allocates arrays of static size",
+    callees = "rknn"
   )
 }
 
 #' @export
 trainLearner.classif.rknn = function(.learner, .task, .subset, .weights = NULL,  ...){
   z = getTaskData(.task, .subset, target.extra = TRUE)
-  c(list(data = z$data, y = z$target ), list(...))
+  c(list(data = z$data, y = z$target), list(...))
 }
 
 #' @export
 predictLearner.classif.rknn = function(.learner, .model, .newdata, ...){
   args = .model$learner.model
   args$newdata = .newdata
-  do.call(rknn::rknn,args)$pred
+  do.call(rknn::rknn, args)$pred
 }
