@@ -9,7 +9,8 @@ makeRLearner.multilabel.rFerns = function() {
     ),
     properties = c("numerics", "factors", "ordered"),
     name = "Random ferns",
-    short.name = "rFerns"
+    short.name = "rFerns",
+    callees = "rFerns"
   )
 }
 
