@@ -15,7 +15,8 @@ makeRLearner.regr.cubist = function() {
     ),
     properties = c("missings", "numerics", "factors"),
     name = "Cubist",
-    short.name = "cubist"
+    short.name = "cubist",
+    callees = c("cubist", "cubistControl", "predict.cubist")
   )
 }
 
