@@ -7,16 +7,16 @@ makeRLearner.regr.nnet = function() {
       makeIntegerLearnerParam(id = "size", default = 3L, lower = 0L),
       # FIXME nnet() seems to have no default for size, but if it is 3, par.vals is redundant
       makeIntegerLearnerParam(id = "maxit", default = 100L, lower = 1L),
-      makeLogicalLearnerParam(id = "linout", default = FALSE, requires = quote(entropy==FALSE && softmax==FALSE && censored==FALSE)),
-      makeLogicalLearnerParam(id = "entropy", default = FALSE, requires = quote(linout==FALSE && softmax==FALSE && censored==FALSE)),
-      makeLogicalLearnerParam(id = "softmax", default = FALSE, requires = quote(entropy==FALSE && linout==FALSE && censored==FALSE)),
-      makeLogicalLearnerParam(id = "censored", default = FALSE, requires = quote(linout==FALSE && softmax==FALSE && entropy==FALSE)),
+      makeLogicalLearnerParam(id = "linout", default = FALSE, requires = quote(entropy == FALSE && softmax == FALSE && censored == FALSE)),
+      makeLogicalLearnerParam(id = "entropy", default = FALSE, requires = quote(linout == FALSE && softmax == FALSE && censored == FALSE)),
+      makeLogicalLearnerParam(id = "softmax", default = FALSE, requires = quote(entropy == FALSE && linout == FALSE && censored == FALSE)),
+      makeLogicalLearnerParam(id = "censored", default = FALSE, requires = quote(linout == FALSE && softmax == FALSE && entropy == FALSE)),
       makeLogicalLearnerParam(id = "skip", default = FALSE),
       makeNumericLearnerParam(id = "rang", default = 0.7),
       makeNumericLearnerParam(id = "decay", default = 0, lower = 0),
       makeLogicalLearnerParam(id = "Hess", default = FALSE),
       makeLogicalLearnerParam(id = "trace", default = TRUE, tunable = FALSE),
-      makeIntegerLearnerParam(id = "MaxNWts", default = 1000L, lower = 1L),
+      makeIntegerLearnerParam(id = "MaxNWts", default = 1000L, lower = 1L, tunable = FALSE),
       makeNumericLearnerParam(id = "abstol", default = 1.0e-4),
       makeNumericLearnerParam(id = "reltol", default = 1.0e-8)
     ),
@@ -24,7 +24,8 @@ makeRLearner.regr.nnet = function() {
     properties = c("numerics", "factors", "weights"),
     name = "Neural Network",
     short.name = "nnet",
-    note = "`size` has been set to `3` by default."
+    note = "`size` has been set to `3` by default.",
+    callees = "nnet"
   )
 }
 
