@@ -5,36 +5,36 @@
 #' The following stacking methods are available:
 #'
 #'  \describe{
-#'   \item{\code{average}}{Averaging of base learner predictions without weights.}
-#'   \item{\code{stack.nocv}}{Fits the super learner, where in-sample predictions of the base learners are used.}
-#'   \item{\code{stack.cv}}{Fits the super learner, where the base learner predictions are computed
-#'   by crossvalidated predictions (the resampling strategy can be set via the \code{resampling} argument).}
-#'   \item{\code{hill.climb}}{Select a subset of base learner predictions by hill climbing algorithm.}
-#'   \item{\code{compress}}{Train a neural network to compress the model from a collection of base learners.}
+#'   \item{`average`}{Averaging of base learner predictions without weights.}
+#'   \item{`stack.nocv`}{Fits the super learner, where in-sample predictions of the base learners are used.}
+#'   \item{`stack.cv`}{Fits the super learner, where the base learner predictions are computed
+#'   by crossvalidated predictions (the resampling strategy can be set via the `resampling` argument).}
+#'   \item{`hill.climb`}{Select a subset of base learner predictions by hill climbing algorithm.}
+#'   \item{`compress`}{Train a neural network to compress the model from a collection of base learners.}
 #'  }
 #'
-#' @param base.learners [(list of) \code{\link{Learner}}]\cr
-#'   A list of learners created with \code{makeLearner}.
+#' @param base.learners [(list of) [Learner])\cr
+#'   A list of learners created with `makeLearner`.
 #' @param super.learner [\code{\link{Learner} | character(1)}]\cr
 #'   The super learner that makes the final prediction based on the base learners.
-#'   If you pass a string, the super learner will be created via \code{makeLearner}.
-#'   Not used for \code{method = 'average'}. Default is \code{NULL}.
-#' @param predict.type [\code{character(1)}]\cr
-#'   Sets the type of the final prediction for \code{method = 'average'}.
-#'   For other methods, the predict type should be set within \code{super.learner}.
-#'   If the type of the base learner prediction, which is set up within \code{base.learners}, is
+#'   If you pass a string, the super learner will be created via `makeLearner`.
+#'   Not used for `method = 'average'`. Default is `NULL`.
+#' @param predict.type (`character(1)`)\cr
+#'   Sets the type of the final prediction for `method = 'average'`.
+#'   For other methods, the predict type should be set within `super.learner`.
+#'   If the type of the base learner prediction, which is set up within `base.learners`, is
 #'   \describe{
-#'    \item{\code{"prob"}}{then \code{predict.type = 'prob'} will use the average of all
-#'    bease learner predictions and \code{predict.type = 'response'} will use
+#'    \item{`"prob"`}{then `predict.type = 'prob'` will use the average of all
+#'    bease learner predictions and `predict.type = 'response'` will use
 #'    the class with highest probability as final prediction.}
-#'    \item{\code{"response"}}{then, for classification tasks with \code{predict.type = 'prob'},
+#'    \item{`"response"`}{then, for classification tasks with `predict.type = 'prob'`,
 #'    the final prediction will be the relative frequency based on the predicted base learner classes
-#'    and classification tasks with \code{predict.type = 'response'} will use majority vote of the base
+#'    and classification tasks with `predict.type = 'response'` will use majority vote of the base
 #'    learner predictions to determine the final prediction.
 #'    For regression tasks, the final prediction will be the average of the base learner predictions.}
 #'   }
 #'
-#' @param method [\code{character(1)}]\cr
+#' @param method (`character(1)`)\cr
 #'   \dQuote{average} for averaging the predictions of the base learners,
 #'   \dQuote{stack.nocv} for building a super learner using the predictions of the base learners,
 #'   \dQuote{stack.cv} for building a super learner using crossvalidated predictions of the base learners.
@@ -43,24 +43,24 @@
 #'   \dQuote{compress} for compressing the model to mimic the predictions of a collection of base learners
 #'   while speeding up the predictions and reducing the size of the model.
 #'   Default is \dQuote{stack.nocv},
-#' @param use.feat [\code{logical(1)}]\cr
+#' @param use.feat (`logical(1)`)\cr
 #'   Whether the original features should also be passed to the super learner.
-#'   Not used for \code{method = 'average'}.
-#'   Default is \code{FALSE}.
-#' @param resampling [\code{\link{ResampleDesc}}]\cr
-#'   Resampling strategy for \code{method = 'stack.cv'}.
+#'   Not used for `method = 'average'`.
+#'   Default is `FALSE`.
+#' @param resampling ([ResampleDesc])\cr
+#'   Resampling strategy for `method = 'stack.cv'`.
 #'   Currently only CV is allowed for resampling.
-#'   The default \code{NULL} uses 5-fold CV.
-#' @param parset the parameters for \code{hill.climb} method, including
+#'   The default `NULL` uses 5-fold CV.
+#' @param parset the parameters for `hill.climb` method, including
 #' \describe{
-#'   \item{\code{replace}}{Whether a base learner can be selected more than once.}
-#'   \item{\code{init}}{Number of best models being included before the selection algorithm.}
-#'   \item{\code{bagprob}}{The proportion of models being considered in one round of selection.}
-#'   \item{\code{bagtime}}{The number of rounds of the bagging selection.}
-#'   \item{\code{metric}}{The result evaluation metric function taking two parameters \code{pred} and \code{true},
+#'   \item{`replace`}{Whether a base learner can be selected more than once.}
+#'   \item{`init`}{Number of best models being included before the selection algorithm.}
+#'   \item{`bagprob`}{The proportion of models being considered in one round of selection.}
+#'   \item{`bagtime`}{The number of rounds of the bagging selection.}
+#'   \item{`metric`}{The result evaluation metric function taking two parameters `pred` and `true`,
 #'   the smaller the score the better.}
 #' }
-#' the parameters for \code{compress} method, including
+#' the parameters for `compress` method, including
 #' \describe{
 #'    \item{k}{the size multiplier of the generated data}
 #'    \item{prob}{the probability to exchange values}
@@ -87,43 +87,44 @@
 #'     predict.type = "response", method = "compress")
 #'   tmp = train(m, tsk)
 #'   res = predict(tmp, tsk)
+#' @noMd
 #' @export
 makeStackedLearner = function(base.learners, super.learner = NULL, predict.type = NULL,
   method = "stack.nocv", use.feat = FALSE, resampling = NULL, parset = list()) {
 
   if (is.character(base.learners)) base.learners = lapply(base.learners, checkLearner)
   if (is.null(super.learner) && method == "compress") {
-    super.learner = makeLearner(stri_paste(base.learners[[1]]$type, '.nnet'))
+    super.learner = makeLearner(stri_paste(base.learners[[1]]$type, ".nnet"))
   }
   if (!is.null(super.learner)) {
     super.learner = checkLearner(super.learner)
     if (!is.null(predict.type)) super.learner = setPredictType(super.learner, predict.type)
   }
 
-  baseType = unique(extractSubList(base.learners, "type"))
+  base.type = unique(extractSubList(base.learners, "type"))
   if (!is.null(resampling) & method != "stack.cv") {
     stop("No resampling needed for this method")
   }
   if (is.null(resampling)) {
-    resampling = makeResampleDesc("CV", iters= 5L,
-      stratify = ifelse(baseType == "classif", TRUE, FALSE))
+    resampling = makeResampleDesc("CV", iters = 5L,
+      stratify = ifelse(base.type == "classif", TRUE, FALSE))
   }
   assertChoice(method, c("average", "stack.nocv", "stack.cv", "hill.climb", "compress"))
   assertClass(resampling, "ResampleDesc")
 
   pts = unique(extractSubList(base.learners, "predict.type"))
-  if ("se"%in%pts | (!is.null(predict.type) && predict.type == "se") |
+  if ("se" %in% pts || (!is.null(predict.type) && predict.type == "se") ||
         (!is.null(super.learner) && super.learner$predict.type == "se"))
     stop("Predicting standard errors currently not supported.")
   if (length(pts) > 1L)
     stop("Base learner must all have the same predict type!")
-  if ((method == "average" | method == "hill.climb") & (!is.null(super.learner) | is.null(predict.type)) )
+  if ((method == "average" || method == "hill.climb") & (!is.null(super.learner) || is.null(predict.type)))
     stop("No super learner needed for this method or the 'predict.type' is not specified.")
   if (method != "average" & method != "hill.climb" & is.null(super.learner))
     stop("You have to specify a super learner for this method.")
   #if (method != "average" & !is.null(predict.type))
   #  stop("Predict type has to be specified within the super learner.")
-  if ((method == "average" | method == "hill.climb") & use.feat)
+  if ((method == "average" || method == "hill.climb") & use.feat)
     stop("The original features can not be used for this method")
   if (!inherits(resampling, "CVDesc"))
     stop("Currently only CV is allowed for resampling!")
@@ -158,10 +159,10 @@ makeStackedLearner = function(base.learners, super.learner = NULL, predict.type
 #'
 #' @description Returns the predictions for each base learner.
 #'
-#' @param model [\code{WrappedModel}]\cr Wrapped model, result of train.
-#' @param newdata [\code{data.frame}]\cr
+#' @param model ([WrappedModel`)\cr Wrapped model, result of train.
+#' @param newdata ([data.frame])\cr
 #' New observations, for which the predictions using the specified base learners should be returned.
-#' Default is \code{NULL} and extracts the base learner predictions that were made during the training.
+#' Default is `NULL` and extracts the base learner predictions that were made during the training.
 #'
 #' @details None.
 #'
@@ -179,7 +180,7 @@ getStackedBaseLearnerPredictions = function(model, newdata = NULL) {
     probs = vector("list", length(bms))
     for (i in seq_along(bms)) {
       pred = predict(bms[[i]], newdata = newdata)
-      probs[[i]] = getResponse(pred, full.matrix = ifelse(method %in% c("average","hill.climb"), TRUE, FALSE))
+      probs[[i]] = getResponse(pred, full.matrix = ifelse(method %in% c("average", "hill.climb"), TRUE, FALSE))
     }
 
     names(probs) = sapply(bms, function(X) X$learner$id) #names(.learner$base.learners)
@@ -230,12 +231,12 @@ predictLearner.StackedLearner = function(.learner, .model, .newdata, ...) {
     if (.learner$method == "hill.climb") {
       model.weight = .model$learner.model$weights
     } else {
-      model.weight = rep(1/length(probs), length(probs))
+      model.weight = rep(1 / length(probs), length(probs))
     }
     if (bms.pt == "prob") {
       # if base learner predictions are probabilities for classification
-      for (i in 1:length(probs))
-        probs[[i]] = probs[[i]]*model.weight[i]
+      for (i in seq_along(probs))
+        probs[[i]] = probs[[i]] * model.weight[i]
       prob = Reduce("+", probs)
       if (sm.pt == "prob") {
         # if super learner predictions should be probabilities
@@ -253,7 +254,7 @@ predictLearner.StackedLearner = function(.learner, .model, .newdata, ...) {
           # if super learner predictions should be probabilities, iter over rows to get proportions
           # FIXME: this is very slow + CUMBERSOME. we also do it in more places
           # we need a bbmisc fun for counting proportions in rows or cols
-          #probs = apply(probs, 1L, function(x) (table(factor(x, td$class.levels) )/length(x)))
+          #probs = apply(probs, 1L, function(x) (table(factor(x, td$class.levels))/length(x)))
           #return(setColNames(t(probs), td$class.levels))
           probs = rowiseRatio(probs, td$class.levels, model.weight)
           return(probs)
@@ -282,12 +283,12 @@ predictLearner.StackedLearner = function(.learner, .model, .newdata, ...) {
     feat = .newdata[, colnames(.newdata) %nin% td$target, drop = FALSE]
 
     if (use.feat) {
-      predData = cbind(probs, feat)
+      pred.data = cbind(probs, feat)
     } else {
-      predData = probs
+      pred.data = probs
     }
 
-    pred = predict(sm, newdata = predData)
+    pred = predict(sm, newdata = pred.data)
     if (sm.pt == "prob") {
       return(as.matrix(getPredictionProbabilities(pred, cl = td$class.levels)))
     } else {
@@ -301,7 +302,7 @@ predictLearner.StackedLearner = function(.learner, .model, .newdata, ...) {
 setPredictType.StackedLearner = function(learner, predict.type) {
   lrn = setPredictType.Learner(learner, predict.type)
   lrn$predict.type = predict.type
-  if ("super.learner"%in%names(lrn)) lrn$super.learner$predict.type = predict.type
+  if ("super.learner" %in% names(lrn)) lrn$super.learner$predict.type = predict.type
   return(lrn)
 }
 
@@ -343,10 +344,10 @@ stackNoCV = function(learner, task) {
 
   pred.train = probs
 
-  if (type == "regr" | type == "classif") {
+  if (type == "regr" || type == "classif") {
     probs = as.data.frame(probs)
   } else {
-    probs = as.data.frame(lapply(probs, function(X) X)) #X[,-ncol(X)]))
+    probs = as.data.frame(lapply(probs, function(X) X)) #X[, -ncol(X)]))
   }
 
   # now fit the super learner for predicted_probs --> target
@@ -385,10 +386,10 @@ stackCV = function(learner, task) {
   }
   names(probs) = names(bls)
 
-  if (type == "regr" | type == "classif") {
+  if (type == "regr" || type == "classif") {
     probs = as.data.frame(probs)
   } else {
-    probs = as.data.frame(lapply(probs, function(X) X)) #X[,-ncol(X)]))
+    probs = as.data.frame(lapply(probs, function(X) X)) #X[, -ncol(X)]))
   }
 
   # add true target column IN CORRECT ORDER
@@ -404,9 +405,9 @@ stackCV = function(learner, task) {
   if (use.feat) {
     # add data with normal features IN CORRECT ORDER
     feat = getTaskData(task)#[test.inds, ]
-    feat = feat[, !colnames(feat)%in%tn, drop = FALSE]
-    predData = cbind(probs, feat)
-    super.task = makeSuperLearnerTask(learner, data = predData, target = tn)
+    feat = feat[, !colnames(feat) %in% tn, drop = FALSE]
+    pred.data = cbind(probs, feat)
+    super.task = makeSuperLearnerTask(learner, data = pred.data, target = tn)
   } else {
     super.task = makeSuperLearnerTask(learner, data = probs, target = tn)
   }
@@ -428,12 +429,12 @@ hillclimbBaseLearners = function(learner, task, replace = TRUE, init = 0, bagpro
                 ifelse(length(td$class.levels) == 2L, "classif", "multiclassif"))
   if (is.null(metric)) {
     if (type == "regr") {
-      metric = function(pred, true) mean((pred-true)^2)
+      metric = function(pred, true) mean((pred - true)^2)
     } else {
       metric = function(pred, true) {
         pred = colnames(pred)[max.col(pred)]
         tb = table(pred, true)
-        return( 1- sum(diag(tb))/sum(tb) )
+        return(1 - sum(diag(tb)) / sum(tb))
       }
     }
   }
@@ -441,7 +442,7 @@ hillclimbBaseLearners = function(learner, task, replace = TRUE, init = 0, bagpro
 
   bls = learner$base.learners
   if (type != "regr") {
-    for (i in 1:length(bls)) {
+    for (i in seq_along(bls)) {
       if (bls[[i]]$predict.type == "response")
         stop("Hill climbing algorithm only takes probability predict type for classification.")
     }
@@ -477,13 +478,13 @@ hillclimbBaseLearners = function(learner, task, replace = TRUE, init = 0, bagpro
   flag = TRUE
   for (bagind in 1:bagtime) {
     # bagging of models
-    bagsize = ceiling(m*bagprob)
+    bagsize = ceiling(m * bagprob)
     bagmodel = sample(1:m, bagsize)
     weight = rep(0, bagsize)
 
     # Initial selection of strongest learners
     inds = NULL
-    if (init>0) {
+    if (init > 0) {
       score = rep(Inf, bagsize)
       for (i in bagmodel) {
         score[i] = metric(probs[[i]], probs[[tn]])
@@ -497,16 +498,16 @@ hillclimbBaseLearners = function(learner, task, replace = TRUE, init = 0, bagpro
     # current.prob = rep(0, nrow(probs))
     current.prob = matrix(0, nrow(probs[[1]]), ncol(probs[[1]]))
     old.score = Inf
-    if (selection.size>0) {
-      current.prob = Reduce('+', probs[selection.ind])
-      old.score = metric(current.prob/selection.size, probs[[tn]])
+    if (selection.size > 0) {
+      current.prob = Reduce("+", probs[selection.ind])
+      old.score = metric(current.prob / selection.size, probs[[tn]])
     }
     flag = TRUE
 
     while (flag) {
       score = rep(Inf, bagsize)
       for (i in bagmodel) {
-        score[i] = metric( (probs[[i]]+current.prob)/(selection.size+1), probs[[tn]] )
+        score[i] = metric((probs[[i]] + current.prob) / (selection.size + 1), probs[[tn]])
       }
       inds = order(score)
       if (!replace) {
@@ -516,19 +517,19 @@ hillclimbBaseLearners = function(learner, task, replace = TRUE, init = 0, bagpro
       }
 
       new.score = score[ind]
-      if (old.score-new.score<1e-8) {
+      if (old.score - new.score < 1e-8) {
         flag = FALSE
       } else {
-        current.prob = current.prob+probs[[ind]]
-        weights[ind] = weights[ind]+1
+        current.prob = current.prob + probs[[ind]]
+        weights[ind] = weights[ind] + 1
         selection.ind = c(selection.ind, ind)
-        selection.size = selection.size+1
+        selection.size = selection.size + 1
         old.score = new.score
       }
     }
     weights[bagmodel] = weights[bagmodel] + weight
   }
-  weights = weights/sum(weights)
+  weights = weights / sum(weights)
 
   list(method = "hill.climb", base.models = base.models, super.model = NULL,
        pred.train = probs, weights = weights)
@@ -553,7 +554,7 @@ compressBaseLearners = function(learner, task, parset = list()) {
   if (type == "regr") {
     new.task = makeRegrTask(data = pseudo.data, target = "target")
     if (is.null(learner$super.learner)) {
-      m = makeLearner("regr.nnet", predict.type = )
+      m = makeLearner("regr.nnet", predict.type = )  # nolint
     } else {
       m = learner$super.learner
     }
@@ -581,9 +582,9 @@ getResponse = function(pred, full.matrix = TRUE) {
     if (full.matrix) {
       # return matrix of probabilities
       td = pred$task.desc
-      predReturn = pred$data[, stri_paste("prob", td$class.levels, sep = ".")]
-      colnames(predReturn) = td$class.levels
-      return(predReturn)
+      pred.return = pred$data[, stri_paste("prob", td$class.levels, sep = ".")]
+      colnames(pred.return) = td$class.levels
+      return(pred.return)
     } else {
       # return only vector of probabilities for binary classification
       return(getPredictionProbabilities(pred))
@@ -608,14 +609,14 @@ rowiseRatio = function(probs, levels, model.weight = NULL) {
   m = length(levels)
   p = ncol(probs)
   if (is.null(model.weight)) {
-    model.weight = rep(1/p, p)
+    model.weight = rep(1 / p, p)
   }
-  mat = matrix(0,nrow(probs),m)
+  mat = matrix(0, nrow(probs), m)
   for (i in 1:m) {
-    ids = matrix(probs==levels[i], nrow(probs), p)
+    ids = matrix(probs == levels[i], nrow(probs), p)
     for (j in 1:p)
-      ids[,j] = ids[,j]*model.weight[j]
-    mat[,i] = rowSums(ids)
+      ids[, j] = ids[, j] * model.weight[j]
+    mat[, i] = rowSums(ids)
   }
   colnames(mat) = levels
   return(mat)
@@ -627,8 +628,8 @@ getPseudoData = function(.data, k = 3, prob = 0.1, s = NULL, ...) {
   ori.names = names(.data)
   feat.class = sapply(.data, class)
   ind2 = which(feat.class == "factor")
-  ind1 = setdiff(1:ncol(.data), ind2)
-  if (length(ind2)>0)
+  ind1 = setdiff(seq_len(ncol(.data)), ind2)
+  if (length(ind2) > 0)
     ori.labels = lapply(.data[[ind2]], levels)
   .data = lapply(.data, as.numeric)
   .data = as.data.frame(.data)
@@ -636,14 +637,14 @@ getPseudoData = function(.data, k = 3, prob = 0.1, s = NULL, ...) {
   mn = rep(0, ncol(.data))
   mx = rep(0, ncol(.data))
   for (i in ind1) {
-    mn[i] = min(.data[,i])
-    mx[i] = max(.data[,i])
-    .data[, i] = (.data[, i]-mn[i])/(mx[i]-mn[i])
+    mn[i] = min(.data[, i])
+    mx[i] = max(.data[, i])
+    .data[, i] = (.data[, i] - mn[i]) / (mx[i] - mn[i])
   }
   if (is.null(s)) {
     s = rep(0, ncol(.data))
     for (i in ind1) {
-      s[i] = sd(.data[,i])
+      s[i] = sd(.data[, i])
     }
   }
   testNumeric(s, len = ncol(.data), lower = 0)
@@ -652,13 +653,13 @@ getPseudoData = function(.data, k = 3, prob = 0.1, s = NULL, ...) {
   hamming = function(mat) {
     n = nrow(mat)
     m = ncol(mat)
-    res = matrix(0,n,n)
+    res = matrix(0, n, n)
     for (j in 1:m) {
-      unq = unique(mat[,j])
+      unq = unique(mat[, j])
       p = length(unq)
       for (i in 1:p) {
-        ind = which(mat[,j] == unq[i])
-        res[ind, -ind] = res[ind, -ind]+1
+        ind = which(mat[, j] == unq[i])
+        res[ind, -ind] = res[ind, -ind] + 1
       }
     }
     return(res)
@@ -666,16 +667,16 @@ getPseudoData = function(.data, k = 3, prob = 0.1, s = NULL, ...) {
 
   one.nn = function(mat, ind1, ind2) {
     n = nrow(mat)
-    dist.mat.1 = matrix(0,n,n)
-    dist.mat.2 = matrix(0,n,n)
-    if (length(ind1)>0) {
-      dist.mat.1 = as.matrix(stats::dist(mat[,ind1, drop = FALSE]))
+    dist.mat.1 = matrix(0, n, n)
+    dist.mat.2 = matrix(0, n, n)
+    if (length(ind1) > 0) {
+      dist.mat.1 = as.matrix(stats::dist(mat[, ind1, drop = FALSE]))
     }
-    if (length(ind2)>0) {
-      dist.mat.2 = hamming(mat[,ind2, drop = FALSE])
+    if (length(ind2) > 0) {
+      dist.mat.2 = hamming(mat[, ind2, drop = FALSE])
     }
-    dist.mat = dist.mat.1+dist.mat.2
-    neighbour = max.col( -dist.mat - diag(Inf, n))
+    dist.mat = dist.mat.1 + dist.mat.2
+    neighbour = max.col(-dist.mat - diag(Inf, n))
     return(neighbour)
   }
 
@@ -686,7 +687,7 @@ getPseudoData = function(.data, k = 3, prob = 0.1, s = NULL, ...) {
   p = ncol(.data)
   for (loop in 1:k) {
     data = .data
-    prob.mat = matrix(sample(c(0,1), n*p, replace = TRUE, prob = c(prob, 1-prob)), n, p)
+    prob.mat = matrix(sample(c(0, 1), n * p, replace = TRUE, prob = c(prob, 1 - prob)), n, p)
     prob.mat = prob.mat == 0
     for (i in 1:n) {
       e = as.numeric(data[i, ])
@@ -694,29 +695,29 @@ getPseudoData = function(.data, k = 3, prob = 0.1, s = NULL, ...) {
 
       # continuous
       for (j in ind1) {
-        if (prob.mat[i,j]) {
-          current.sd = abs(e[j]-ee[j])/s[j]
-          tmp1 = rnorm(1,ee[j], current.sd)
-          tmp2 = rnorm(1,e[j], current.sd)
+        if (prob.mat[i, j]) {
+          current.sd = abs(e[j] - ee[j]) / s[j]
+          tmp1 = rnorm(1, ee[j], current.sd)
+          tmp2 = rnorm(1, e[j], current.sd)
           e[j] = tmp1
           ee[j] = tmp2
         }
       }
       for (j in ind2) {
-        if (prob.mat[i,j]) {
+        if (prob.mat[i, j]) {
           tmp = e[j]
           e[j] = ee[j]
           ee[j] = tmp
         }
       }
 
-      data[i,] = ee
-      data[neighbour[i],] = e
+      data[i, ] = ee
+      data[neighbour[i], ] = e
     }
     res = rbind(res, data)
   }
   for (i in ind1)
-    res[,i] = res[,i]*(mx[i]-mn[i])+mn[i]
+    res[, i] = res[, i] * (mx[i] - mn[i]) + mn[i]
   res = data.frame(res)
   names(res) = ori.names
   for (i in ind2)
@@ -724,7 +725,7 @@ getPseudoData = function(.data, k = 3, prob = 0.1, s = NULL, ...) {
   return(res)
 }
 
-# TODOs:
+# FIXMEs:
 # - document + test + export
 # - benchmark stuff on openml
 # - allow base.learners to be character of learners (not only list of learners)
