@@ -1,18 +1,18 @@
 # learner with error "foo" in predict
-makeRLearner.classif.__mlrmocklearners__1 = function() {
+makeRLearner.classif.__mlrmocklearners__1 = function() {  # nolint
   makeRLearnerClassif(
     cl = "classif.__mlrmocklearners__1", package = character(0L), par.set = makeParamSet(),
     properties = c("twoclass", "multiclass", "missings", "numerics", "factors", "prob")
   )
 }
-trainLearner.classif.__mlrmocklearners__1 = function(.learner, .task, .subset, .weights = NULL,  ...) list()
-predictLearner.classif.__mlrmocklearners__1 = function(.learner, .model, .newdata, ...) stop("foo")
+trainLearner.classif.__mlrmocklearners__1 = function(.learner, .task, .subset, .weights = NULL,  ...) list()  # nolint
+predictLearner.classif.__mlrmocklearners__1 = function(.learner, .model, .newdata, ...) stop("foo")  # nolint
 registerS3method("makeRLearner", "classif.__mlrmocklearners__1", makeRLearner.classif.__mlrmocklearners__1)
 registerS3method("trainLearner", "classif.__mlrmocklearners__1", trainLearner.classif.__mlrmocklearners__1)
 registerS3method("predictLearner", "classif.__mlrmocklearners__1", predictLearner.classif.__mlrmocklearners__1)
 
 # for tuning, produces errors en masse
-makeRLearner.classif.__mlrmocklearners__2 = function() {
+makeRLearner.classif.__mlrmocklearners__2 = function() {  # nolint
   makeRLearnerClassif(
     cl = "classif.__mlrmocklearners__2", package = character(0L),
     par.set = makeParamSet(
@@ -21,12 +21,12 @@ makeRLearner.classif.__mlrmocklearners__2 = function() {
     properties = c("twoclass", "multiclass", "missings", "numerics", "factors", "prob")
   )
 }
-trainLearner.classif.__mlrmocklearners__2 = function(.learner, .task, .subset, .weights = NULL, alpha, ...) {
+trainLearner.classif.__mlrmocklearners__2 = function(.learner, .task, .subset, .weights = NULL, alpha, ...) {  # nolint
   if (alpha < 0.5)
     stop("foo")
   list()
 }
-predictLearner.classif.__mlrmocklearners__2 = function(.learner, .model, .newdata, ...) {
+predictLearner.classif.__mlrmocklearners__2 = function(.learner, .model, .newdata, ...) {  # nolint
   as.factor(sample(.model$task.desc$class.levels, nrow(.newdata), replace = TRUE))
 }
 registerS3method("makeRLearner", "classif.__mlrmocklearners__2", makeRLearner.classif.__mlrmocklearners__2)
@@ -35,20 +35,20 @@ registerS3method("predictLearner", "classif.__mlrmocklearners__2", predictLearne
 
 
 # learner with error "foo" in train
-makeRLearner.classif.__mlrmocklearners__3 = function() {
+makeRLearner.classif.__mlrmocklearners__3 = function() {  # nolint
   makeRLearnerClassif(
     cl = "classif.__mlrmocklearners__3", package = character(0L), par.set = makeParamSet(),
     properties = c("twoclass", "multiclass", "missings", "numerics", "factors", "prob")
   )
 }
-trainLearner.classif.__mlrmocklearners__3 = function(.learner, .task, .subset, .weights = NULL,  ...) stop("foo")
-predictLearner.classif.__mlrmocklearners__3 = function(.learner, .model, .newdata, ...) 1L
+trainLearner.classif.__mlrmocklearners__3 = function(.learner, .task, .subset, .weights = NULL,  ...) stop("foo")  # nolint
+predictLearner.classif.__mlrmocklearners__3 = function(.learner, .model, .newdata, ...) 1L  # nolint
 registerS3method("makeRLearner", "classif.__mlrmocklearners__3", makeRLearner.classif.__mlrmocklearners__3)
 registerS3method("trainLearner", "classif.__mlrmocklearners__3", trainLearner.classif.__mlrmocklearners__3)
 registerS3method("predictLearner", "classif.__mlrmocklearners__3", predictLearner.classif.__mlrmocklearners__3)
 
 # learner with different "when" settings for hyperpars
-makeRLearner.regr.__mlrmocklearners__4 = function() {
+makeRLearner.regr.__mlrmocklearners__4 = function() {  # nolint
   makeRLearnerRegr(
     cl = "regr.__mlrmocklearners__4", package = character(0L),
     par.set = makeParamSet(
@@ -60,11 +60,11 @@ makeRLearner.regr.__mlrmocklearners__4 = function() {
   )
 }
 
-trainLearner.regr.__mlrmocklearners__4 = function(.learner, .task, .subset, .weights = NULL, p1, p3, ...) {
+trainLearner.regr.__mlrmocklearners__4 = function(.learner, .task, .subset, .weights = NULL, p1, p3, ...) {  # nolint
   list(foo = p1 + p3)
 }
 
-predictLearner.regr.__mlrmocklearners__4 = function(.learner, .model, .newdata, p2, p3) {
+predictLearner.regr.__mlrmocklearners__4 = function(.learner, .model, .newdata, p2, p3) {  # nolint
   y = rep(1, nrow(.newdata))
   y * .model$learner.model$foo + p2 + p3
 }
@@ -74,7 +74,7 @@ registerS3method("predictLearner", "regr.__mlrmocklearners__4", predictLearner.r
 
 
 # Learner cannot use expression in param requires
-makeRLearner.classif.__mlrmocklearners__5 = function() {
+makeRLearner.classif.__mlrmocklearners__5 = function() {  # nolint
   makeRLearnerClassif(
     cl = "classif.__mlrmocklearners__5",
     package = "mlr",
@@ -86,9 +86,9 @@ makeRLearner.classif.__mlrmocklearners__5 = function() {
   )
 }
 
-trainLearner.classif.__mlrmocklearners__5 = function(.learner, .task, .subset, .weights = NULL, ...) { }
+trainLearner.classif.__mlrmocklearners__5 = function(.learner, .task, .subset, .weights = NULL, ...) { }  # nolint
 
-predictLearner.classif.__mlrmocklearners__5 = function(.learner, .model, .newdata) {
+predictLearner.classif.__mlrmocklearners__5 = function(.learner, .model, .newdata) {  # nolint
   rep(factor(.model$factor.levels[[.model$task.desc$target]][1]), nrow(.newdata))
 }
 registerS3method("makeRLearner", "classif.__mlrmocklearners__5", makeRLearner.classif.__mlrmocklearners__5)
@@ -96,7 +96,7 @@ registerS3method("trainLearner", "classif.__mlrmocklearners__5", trainLearner.cl
 registerS3method("predictLearner", "classif.__mlrmocklearners__5", predictLearner.classif.__mlrmocklearners__5)
 
 # stores weights internally so we can see wether they are correctly passed down
-makeRLearner.regr.__mlrmocklearners__6 = function() {
+makeRLearner.regr.__mlrmocklearners__6 = function() {  # nolint
   makeRLearnerRegr(
     cl = "regr.__mlrmocklearners__6", package = character(0L),
     par.set = makeParamSet(),
@@ -104,17 +104,36 @@ makeRLearner.regr.__mlrmocklearners__6 = function() {
   )
 }
 
-trainLearner.regr.__mlrmocklearners__6 = function(.learner, .task, .subset, .weights = NULL, ...) {
+trainLearner.regr.__mlrmocklearners__6 = function(.learner, .task, .subset, .weights = NULL, ...) {  # nolint
   list(weights = .weights)
 }
 
-predictLearner.regr.__mlrmocklearners__6 = function(.learner, .model, .newdata ) {
+predictLearner.regr.__mlrmocklearners__6 = function(.learner, .model, .newdata) {  # nolint
   rep(1, nrow(.newdata))
 }
 registerS3method("makeRLearner", "regr.__mlrmocklearners__6", makeRLearner.regr.__mlrmocklearners__6)
 registerS3method("trainLearner", "regr.__mlrmocklearners__6", trainLearner.regr.__mlrmocklearners__6)
 registerS3method("predictLearner", "regr.__mlrmocklearners__6", predictLearner.regr.__mlrmocklearners__6)
 
+makeRLearner.classif.__mlrmocklearners__6 = function() {  # nolint
+  makeRLearnerClassif(
+    cl = "classif.__mlrmocklearners__6", package = character(0L),
+    par.set = makeParamSet(),
+    properties = c("missings", "numerics", "factors", "weights", "twoclass", "multiclass")
+  )
+}
+
+trainLearner.classif.__mlrmocklearners__6 = function(.learner, .task, .subset, .weights = NULL, ...) {  # nolint
+  list(weights = .weights)
+}
+
+predictLearner.classif.__mlrmocklearners__6 = function(.learner, .model, .newdata) {  # nolint
+  rep(1, nrow(.newdata))
+}
+registerS3method("makeRLearner", "classif.__mlrmocklearners__6", makeRLearner.classif.__mlrmocklearners__6)
+registerS3method("trainLearner", "classif.__mlrmocklearners__6", trainLearner.classif.__mlrmocklearners__6)
+registerS3method("predictLearner", "classif.__mlrmocklearners__6", predictLearner.classif.__mlrmocklearners__6)
+
 
 
 
