@@ -19,7 +19,7 @@ test_that("classif_bst", {
 
   old.predicts.list = list()
 
-  for (i in 1:length(parset.list1)) {
+  for (i in seq_along(parset.list1)) {
     parset = parset.list1[[i]]
     parset$y = ifelse(binaryclass.train[, binaryclass.class.col] == binaryclass.class.levs[2], 1, -1)
     parset$x = binaryclass.train[, -binaryclass.class.col]
