@@ -12,7 +12,7 @@ test_that("classif_glmnet", {
   old.predicts.list = list()
   old.probs.list = list()
 
-  for (i in 1:length(parset.list)) {
+  for (i in seq_along(parset.list)) {
     parset = parset.list[[i]]
     s = parset[["s"]]
     if (is.null(s))
@@ -22,7 +22,7 @@ test_that("classif_glmnet", {
     y = x[, binaryclass.class.col]
     x[, binaryclass.class.col] = NULL
     pars = list(x = as.matrix(x), y = y, family = "binomial")
-    pars = c(pars, parset)    
+    pars = c(pars, parset)
     glmnet::glmnet.control(factory = TRUE)
     ctrl.args = names(formals(glmnet::glmnet.control))
     set.seed(getOption("mlr.debug.seed"))
@@ -35,15 +35,15 @@ test_that("classif_glmnet", {
     }
     newx = binaryclass.test
     newx[, binaryclass.class.col] = NULL
-    p = factor(predict(m, as.matrix(newx), type = "class", s = s)[,1])
-    p2 = predict(m, as.matrix(newx), type = "response", s = s)[,1]
+    p = factor(predict(m, as.matrix(newx), type = "class", s = s)[, 1])
+    p2 = predict(m, as.matrix(newx), type = "response", s = s)[, 1]
     old.predicts.list[[i]] = p
     old.probs.list[[i]] = 1 - p2
   }
 
   testSimpleParsets("classif.glmnet", binaryclass.df, binaryclass.target,
     binaryclass.train.inds, old.predicts.list, parset.list)
-  testProbParsets ("classif.glmnet", binaryclass.df, binaryclass.target,
+  testProbParsets("classif.glmnet", binaryclass.df, binaryclass.target,
     binaryclass.train.inds, old.probs.list, parset.list)
 
 })
